<!DOCTYPE html>
<html>
<!--
Experiment programmed by Nina Selina Müller (nina.mueller2@unifr.ch)
using jspsych-6.0.5 (jspsych.org).

This experiment consists of five parts:
1) participants answer a few personal questions (index.php)
2) participants see 40 German-English word pairs twice in randomized order for 8 seconds each.
3) participants solve easy math problems for 5 minutes
4) participants translate half of the word pairs productively (G-E) and the other half receptively (E-G)
   (instructions and uebersetzungen _ productive or receptive.php)
5) participants take a 5 min vocabulary test (word / non-word)
   (surveynina_nonwords.html)
-->

<?php include  "wordlists/produceStimuliList.php" ?>
    <head>
        <title>Vocablary Learning Activity 1</title>
        <script src ="../jspsych-6.0.5/jspsych.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-html-keyboard-response.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-survey-text.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-instructions.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-survey-multi-choice.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-survey-likert.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-survey-multi-select.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-image-button-response.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-image-keyboard-response.js"></script>
        <script src = "../jspsych-6.0.5/plugins/jspsych-html-button-response.js"></script>
        <link href = "../jspsych-6.0.5/css/jspsych.css" rel="stylesheet" type="text/css"></link>
        <meta charset= "UTF-8">
    </head>
    <body></body>
    <script>
    
//////////////////////////// Welcome //////////////////////////
/////////////////////// Notice  //////////////////

var welcome = {
    type: 'instructions',
    pages: ["<p> <h1> Herzlich Willkommen!</h1></p>" +
    "<p> Das ist ein Experiment für eine Masterarbeit der Universität Fribourg mit folgenden Teilen: </p>" +
    "<p><i> 1. Fragen zur Person beantworten (hast du bereits geschafft!); </p>" +
    "<p> 2. Zwei Präsentationen ansehen; </p>" +
    "<p> 3. Mathematikaufgaben lösen; </p>" +
    "<p> 4. Wörter übersetzen; </p>" +
    "<p> 5. Ankreuzen, welche Wörter du bereits kennst.</i> </p>" +
    "<p> Deine Antworten werden anonymisiert, so dass niemand deine Ergebnisse zurückverfolgen kann.</p>"+
    "<p>Es gibt also keine Noten. Versuche einfach, dein Bestes zu geben. </p>" +
    "<p> Bist du bereit? Dann drücke auf <i>weiter</i>.</p>"],
    show_clickable_nav: true,
    button_label_next: "weiter"
};


//////////////////////////// Parts 1&2 //////////////////////////
///////////////////..//// Presentation  //////////////////

// Instructions 1
var instructions1 = {
    type: 'instructions',
    pages: [
    "<p><h1> Teil 2a </h1> </p>" +
    "<p> Du wirst gleich knapp 5 Minuten lang eine Präsentation sehen von insgesamt 30 deutsch-englischen Wortpaaren.</p>" +
    "<p>Jedes Wortpaar wird 8 Sekunden lang gezeigt. Dann kommt automatisch das nächste.</p>" +
    "<p>Zum Beispiel:</p>" +
    "<p><h1>Apfel - apple</h1></p>" +
    "<p>Versuche dir so viele davon wie möglich zu merken.</p>" +
    "<p>Bist du bereit?</p>"+
    "<p>Dann beginne die Präsentation, indem du auf <i>weiter</i> drückst.</p>"],
    show_clickable_nav: true,
    button_label_next: "weiter"
};
// Stimuli 1: German-English word pairs for presentation
<?php produceStimuliList("wordlists/germanenglishlist.csv","wordpairs1_stimuli") ?>

// Presentation 1
var fixation1 = {
  type: "html-keyboard-response",
  stimulus: jsPsych.timelineVariable('stimulus'),
  choices: jsPsych.NO_KEYS,
  trial_duration: 8000,
  post_trial_gap: 80,
}
var presentation1 = {
  timeline: [fixation1],
  timeline_variables: wordpairs1_stimuli,
  randomize_order: true
}

// Instructions 2
var instructions2 = {
    type: "instructions",
    pages: [
    "<p><h1> Teil 2b </h1> </p>" +
    "<p>Nun wirst du dieselben Wortpaare noch einmal sehen, aber in umgekehrter Reihenfolge, also englisch-deutsch.</p>" +
    "<p>Zum Beispiel:</p>" +
    "<p><h1>apple - Apfel</h1></p>" +
    "<p>Versuche wieder, dir so viele davon wie möglich zu merken.</p>" +
    "<p>Bist du bereit?</p>"+
    "<p>Dann beginne die Präsentation, indem du auf <i>weiter</i> drückst.</p>"],
    show_clickable_nav: true,
    button_label_next: "weiter"
};

// Stimuli 2: English-German word pairs for presentation
<?php produceStimuliList("wordlists/englishgermanlist.csv","wordpairs2_stimuli") ?>

// Presentation 2
var fixation2 = {
  type: "html-keyboard-response",
  stimulus: jsPsych.timelineVariable('stimulus'),
  choices: jsPsych.NO_KEYS,
  trial_duration: 8000,
  post_trial_gap: 80,
}
var presentation2 = {
  timeline: [fixation2],
  timeline_variables: wordpairs2_stimuli,
  randomize_order: true
}

//////////////////////////////// Part 3 /////////////////////////////
/////////////////////////// Math problems //////////////////

// Instructions 3
var instructions3 = {
    type: "instructions",
    pages: [
      "<p><h1> Teil 3 </h1> </p>" +
    "<p>In den nächsten fünf Minuten wirst du ein paar Mathematik-Aufgaben lösen.</p>" +
    "<p>Rechne im Kopf und schreibe die Lösungen auf das leere Blatt Papier.</p>" +
    "<p>Du wirst nicht alle Aufgaben lösen können; versuche einfach, so viele wie möglich zu schaffen.</p>" +
    "<p>Das * Zeichen bedeutet, dass du Mal rechnen sollst.</p>"+
    "<p>Bist du bereit?</p>"+
    "<p>Die Aufgaben werden 5 Minuten lang gezeigt, sobald du auf <i>weiter</i> drückst.</p>"],
    show_clickable_nav: true,
    button_label_next: "Weiter"
};

// Matheaufgaben
var image = {
    type: 'image-keyboard-response',
    stimulus: 'math.jpg',
    choices: jsPsych.NO_KEYS,
    prompt: "<p> Rechne im Kopf. Schreibe die Antworten auf ein Blatt.</p>",
    trial_duration: 300000
};

// Instructions 3b
var instructions3b = {
    type: "instructions",
    pages: [
    "<p>Fertig gerechnet! </p>" +
    "<p>Bringe das Blatt deiner Lehrperson. </p>" +
    "<p>Drücke auf <i>weiter</i>, um mit Teil 4 zu beginnen.</p>"],
    show_clickable_nav: true,
    button_label_next: "weiter"
};

////////////////////////// Finalizing /////////////////////////
////////////////// Timeline and running the experiment ///////////

var timeline = [];
timeline.push(welcome);
timeline.push(instructions1);
timeline.push(presentation1);
timeline.push(instructions2);
timeline.push(presentation2);
timeline.push(instructions3);
timeline.push(image);
timeline.push(instructions3b);

// jsPsych.init({timeline: timeline});


// Datum hinzufügen
jsPsych.data.addProperties({LocalDate: Date()});

// Die Vpn-ID ist teil des URLs (ninasurvey.php?ID=blabla). Rauslesen:
// source: https://css-tricks.com/snippets/javascript/get-url-variables/
function getQueryVariable(variable)
{
       var query = window.location.search.substring(1);
       var vars = query.split("&");
       for (var i=0;i<vars.length;i++) {
               var pair = vars[i].split("=");
               if(pair[0] == variable){return pair[1];}
       }
       return(false);
}
var SubjectID = getQueryVariable("ID");
jsPsych.data.addProperties({SubjectID: SubjectID});

// URL zum Weiterleiten definieren
var urlvar = ["instructions_productive.php?ID="+SubjectID];

function saveData(name, data){
  var xhr = new XMLHttpRequest();
  xhr.open('POST', 'write_data.php'); // 'write_data.php' is the path to the php file described above.
  xhr.setRequestHeader('Content-Type', 'application/json');
  xhr.send(JSON.stringify({filename: name, filedata: data}));
}

// call the saveData function after the experiment is over
jsPsych.init({
	 timeline: timeline,
   // code to define the experiment structure would go here...  
   on_finish: function(){ saveData(SubjectID, jsPsych.data.get().csv());
    window.location = urlvar;
}
});

// Muss noch herausfinden, wie man nach Ablauf auf eine andere Seite kommt.
// https://groups.google.com/forum/#!topic/jspsych/ryolnvcuO5E

    </script>
</html>
